# ambiviz

[![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)](https://github.com/astral-sh/uv)
[![Actions status](https://github.com/fisheggg/ambiviz/workflows/ci.yml/badge.svg)](https://github.com/fisheggg/ambiviz/actions)


Visualization tools for ambisonic audio (and 360 video).


## References

- The core ambisonics decoder is modified from [https://github.com/pedro-morgado/spatialaudiogen](https://github.com/pedro-morgado/spatialaudiogen).
